==> request-tracker4_4.4.4+dfsg.orig-third-party-source.tar.gz: rt-4.4.4/devel/third-party/ckeditor-src/plugins/table/lang/uk.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'table', 'uk', {
	border: 'Розмір рамки',
	caption: 'Заголовок таблиці',
	cell: {
		menu: 'Комірки',
		insertBefore: 'Вставити комірку перед',
		insertAfter: 'Вставити комірку після',
		deleteCell: 'Видалити комірки',
		merge: 'Об\'єднати комірки',
		mergeRight: 'Об\'єднати справа',
		mergeDown: 'Об\'єднати донизу',
		splitHorizontal: 'Розділити комірку по горизонталі',
		splitVertical: 'Розділити комірку по вертикалі',
		title: 'Властивості комірки',
		cellType: 'Тип комірки',
		rowSpan: 'Об\'єднання рядків',
		colSpan: 'Об\'єднання стовпців',
		wordWrap: 'Автоперенесення тексту',
		hAlign: 'Гориз. вирівнювання',
		vAlign: 'Верт. вирівнювання',
		alignBaseline: 'По базовій лінії',
		bgColor: 'Колір фону',
		borderColor: 'Колір рамки',
		data: 'Дані',
		header: 'Заголовок',
		yes: 'Так',
		no: 'Ні',
		invalidWidth: 'Ширина комірки повинна бути цілим числом.',
		invalidHeight: 'Висота комірки повинна бути цілим числом.',
		invalidRowSpan: 'Кількість об\'єднуваних рядків повинна бути цілим числом.',
		invalidColSpan: 'Кількість об\'єднуваних стовбців повинна бути цілим числом.',
		chooseColor: 'Обрати'
	},
	cellPad: 'Внутр. відступ',
	cellSpace: 'Проміжок',
	column: {
		menu: 'Стовбці',
		insertBefore: 'Вставити стовбець перед',
		insertAfter: 'Вставити стовбець після',
		deleteColumn: 'Видалити стовбці'
	},
	columns: 'Стовбці',
	deleteTable: 'Видалити таблицю',
	headers: 'Заголовки стовбців/рядків',
	headersBoth: 'Стовбці і рядки',
	headersColumn: 'Стовбці',
	headersNone: 'Без заголовків',
	headersRow: 'Рядки',
	invalidBorder: 'Розмір рамки повинен бути цілим числом.',
	invalidCellPadding: 'Внутр. відступ комірки повинен бути цілим числом.',
	invalidCellSpacing: 'Проміжок між комірками повинен бути цілим числом.',
	invalidCols: 'Кількість стовбців повинна бути більшою 0.',
	invalidHeight: 'Висота таблиці повинна бути цілим числом.',
	invalidRows: 'Кількість рядків повинна бути більшою 0.',
	invalidWidth: 'Ширина таблиці повинна бути цілим числом.',
	menu: 'Властивості таблиці',
	row: {
		menu: 'Рядки',
		insertBefore: 'Вставити рядок перед',
		insertAfter: 'Вставити рядок після',
		deleteRow: 'Видалити рядки'
	},
	rows: 'Рядки',
	summary: 'Детальний опис заголовку таблиці',
	title: 'Властивості таблиці',
	toolbar: 'Таблиця',
	widthPc: 'відсотків',
	widthPx: 'пікселів',
	widthUnit: 'Одиниці вимір.'
} );

==> request-tracker5_5.0.7+dfsg.orig-third-party-source.tar.gz: rt-5.0.7/devel/third-party/ckeditor-src/plugins/table/lang/uk.js <==
/*
Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'table', 'uk', {
	border: 'Розмір рамки',
	caption: 'Заголовок таблиці',
	cell: {
		menu: 'Комірки',
		insertBefore: 'Вставити комірку перед',
		insertAfter: 'Вставити комірку після',
		deleteCell: 'Видалити комірки',
		merge: 'Об\'єднати комірки',
		mergeRight: 'Об\'єднати справа',
		mergeDown: 'Об\'єднати донизу',
		splitHorizontal: 'Розділити комірку по горизонталі',
		splitVertical: 'Розділити комірку по вертикалі',
		title: 'Властивості комірки',
		cellType: 'Тип комірки',
		rowSpan: 'Об\'єднання рядків',
		colSpan: 'Об\'єднання стовпців',
		wordWrap: 'Автоперенесення тексту',
		hAlign: 'Гориз. вирівнювання',
		vAlign: 'Верт. вирівнювання',
		alignBaseline: 'По базовій лінії',
		bgColor: 'Колір фону',
		borderColor: 'Колір рамки',
		data: 'Дані',
		header: 'Заголовок',
		columnHeader: 'Column Header', // MISSING
		rowHeader: 'Row Header', // MISSING
		yes: 'Так',
		no: 'Ні',
		invalidWidth: 'Ширина комірки повинна бути цілим числом.',
		invalidHeight: 'Висота комірки повинна бути цілим числом.',
		invalidRowSpan: 'Кількість об\'єднуваних рядків повинна бути цілим числом.',
		invalidColSpan: 'Кількість об\'єднуваних стовбців повинна бути цілим числом.',
		chooseColor: 'Обрати'
	},
	cellPad: 'Внутр. відступ',
	cellSpace: 'Проміжок',
	column: {
		menu: 'Стовбці',
		insertBefore: 'Вставити стовбець перед',
		insertAfter: 'Вставити стовбець після',
		deleteColumn: 'Видалити стовбці'
	},
	columns: 'Стовбці',
	deleteTable: 'Видалити таблицю',
	headers: 'Заголовки стовбців/рядків',
	headersBoth: 'Стовбці і рядки',
	headersColumn: 'Стовбці',
	headersNone: 'Без заголовків',
	headersRow: 'Рядки',
	heightUnit: 'одиниця висоти',
	invalidBorder: 'Розмір рамки повинен бути цілим числом.',
	invalidCellPadding: 'Внутр. відступ комірки повинен бути цілим числом.',
	invalidCellSpacing: 'Проміжок між комірками повинен бути цілим числом.',
	invalidCols: 'Кількість стовбців повинна бути більшою 0.',
	invalidHeight: 'Висота таблиці повинна бути цілим числом.',
	invalidRows: 'Кількість рядків повинна бути більшою 0.',
	invalidWidth: 'Ширина таблиці повинна бути цілим числом.',
	menu: 'Властивості таблиці',
	row: {
		menu: 'Рядки',
		insertBefore: 'Вставити рядок перед',
		insertAfter: 'Вставити рядок після',
		deleteRow: 'Видалити рядки'
	},
	rows: 'Рядки',
	summary: 'Детальний опис заголовку таблиці',
	title: 'Властивості таблиці',
	toolbar: 'Таблиця',
	widthPc: 'відсотків',
	widthPx: 'пікселів',
	widthUnit: 'одиниця ширини'
} );
